Optimizers
==========

.. automodule:: mumott.optimization.optimizers

.. index::
   single: Class reference; LBFGS 
.. autoclass:: mumott.optimization.optimizers.LBFGS
   :members:
   :undoc-members:
   :inherited-members:
